Index: /trunk/src/VBox/HostDrivers/VBoxNetFlt/win/cfg/VBoxNetCfg.cpp
===================================================================
--- /trunk/src/VBox/HostDrivers/VBoxNetFlt/win/cfg/VBoxNetCfg.cpp	(revision 53317)
+++ /trunk/src/VBox/HostDrivers/VBoxNetFlt/win/cfg/VBoxNetCfg.cpp	(revision 53318)
@@ -2088,9 +2088,5 @@
 }
 
-/*
- * Use the same id as does the old implementation for NDIS 5
- * #define VBOXNETCFGWIN_NETLWF_ID    L"oracle_VBoxNetLwf"
- */
-#define VBOXNETCFGWIN_NETLWF_ID    L"sun_VBoxNetFlt"
+#define VBOXNETCFGWIN_NETLWF_ID    L"oracle_VBoxNetLwf"
 
 static HRESULT vboxNetCfgWinNetLwfUninstall(IN INetCfg *pNc, DWORD InfRmFlags)
Index: /trunk/src/VBox/HostDrivers/VBoxNetFlt/win/ndis6/VBoxNetLwf.inf
===================================================================
--- /trunk/src/VBox/HostDrivers/VBoxNetFlt/win/ndis6/VBoxNetLwf.inf	(revision 53317)
+++ /trunk/src/VBox/HostDrivers/VBoxNetFlt/win/ndis6/VBoxNetLwf.inf	(revision 53318)
@@ -2,6 +2,4 @@
 ; @file
 ; VBoxNetLwf.inf - VirtualBox Bridged Networking Driver inf file
-;
-; Note: We use the same component id as the old NetFlt implementation 
 ;
 ;
@@ -32,11 +30,11 @@
 
 [VBox]
-%VBoxNetLwf_Desc% = VBoxNetLwf.ndi, sun_VBoxNetFlt
+%VBoxNetLwf_Desc% = VBoxNetLwf.ndi, oracle_VBoxNetLwf
 
 [VBox.NTx86]
-%VBoxNetLwf_Desc% = VBoxNetLwf.ndi, sun_VBoxNetFlt
+%VBoxNetLwf_Desc% = VBoxNetLwf.ndi, oracle_VBoxNetLwf
 
 [VBox.NTamd64]
-%VBoxNetLwf_Desc% = VBoxNetLwf.ndi, sun_VBoxNetFlt
+%VBoxNetLwf_Desc% = VBoxNetLwf.ndi, oracle_VBoxNetLwf
 
 [VBoxNetLwf.ndi]
Index: /trunk/src/VBox/Installer/win/InstallHelper/VBoxInstallHelper.cpp
===================================================================
--- /trunk/src/VBox/Installer/win/InstallHelper/VBoxInstallHelper.cpp	(revision 53317)
+++ /trunk/src/VBox/Installer/win/InstallHelper/VBoxInstallHelper.cpp	(revision 53318)
@@ -498,6 +498,4 @@
 
 #define NETLWF_INF_NAME L"VBoxNetLwf.inf"
-#define NETLWF_ID       L"sun_VBoxNetLwf" /** @todo Needs to be changed (?). */
-#define NETADP6_ID      L"sun_VBoxNetAdp6" /** @todo Needs to be changed (?). */
 
 static MSIHANDLE g_hCurrentModule = NULL;
@@ -860,5 +858,5 @@
         if (uErr == ERROR_SUCCESS)
         {
-            WCHAR wszInfName[] = L"VBoxNetLwf.inf";
+            WCHAR wszInfName[] = NETLWF_INF_NAME;
             WCHAR wszInf[MAX_PATH];
             DWORD cchInf = RT_ELEMENTS(wszInf) - sizeof(NETLWF_INF_NAME) - 1;
Index: /trunk/src/VBox/Main/src-server/HostImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/HostImpl.cpp	(revision 53317)
+++ /trunk/src/VBox/Main/src-server/HostImpl.cpp	(revision 53318)
@@ -671,6 +671,11 @@
         hr = pNc->FindComponent(L"MS_TCPIP", &pTcpIpNcc);
 #    else
-        /* for the filter-based approach we get all miniports our filter (sun_VBoxNetFlt)is bound to */
-        hr = pNc->FindComponent(L"sun_VBoxNetFlt", &pTcpIpNcc);
+        /* for the filter-based approach we get all miniports our filter (oracle_VBoxNetLwf)is bound to */
+        hr = pNc->FindComponent(L"oracle_VBoxNetLwf", &pTcpIpNcc);
+        if (hr != S_OK)
+        {
+            /* fall back to NDIS5 miniport lookup (sun_VBoxNetFlt) */
+            hr = pNc->FindComponent(L"sun_VBoxNetFlt", &pTcpIpNcc);
+        }
 #     ifndef VBOX_WITH_HARDENING
         if (hr != S_OK)
@@ -736,5 +741,5 @@
         else
         {
-            LogRel(("failed to get the sun_VBoxNetFlt component, error (0x%x)\n", hr));
+            LogRel(("failed to get the oracle_VBoxNetLwf(sun_VBoxNetFlt) component, error (0x%x)\n", hr));
         }
 
Index: /trunk/src/VBox/Main/src-server/win/NetIf-win.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/win/NetIf-win.cpp	(revision 53317)
+++ /trunk/src/VBox/Main/src-server/win/NetIf-win.cpp	(revision 53318)
@@ -1481,6 +1481,11 @@
         hr = pNc->FindComponent(L"MS_TCPIP", &pTcpIpNcc);
 # else
-        /* for the filter-based approach we get all miniports our filter (sun_VBoxNetFlt)is bound to */
-        hr = pNc->FindComponent(L"sun_VBoxNetFlt", &pTcpIpNcc);
+        /* for the filter-based approach we get all miniports our filter (oracle_VBoxNetLwf)is bound to */
+        hr = pNc->FindComponent(L"oracle_VBoxNetLwf", &pTcpIpNcc);
+        if (hr != S_OK)
+        {
+            /* fall back to NDIS5 miniport lookup (sun_VBoxNetFlt) */
+            hr = pNc->FindComponent(L"sun_VBoxNetFlt", &pTcpIpNcc);
+        }
 #  ifndef VBOX_WITH_HARDENING
         if (hr != S_OK)
@@ -1571,5 +1576,5 @@
         else
         {
-            LogRel(("failed to get the sun_VBoxNetFlt component, error (0x%x)\n", hr));
+            LogRel(("failed to get the oracle_VBoxNetLwf(sun_VBoxNetFlt) component, error (0x%x)\n", hr));
         }
 
